# Nebari Code of Conduct

Nebari is a community-oriented and community-led project.
We value the participation of every member of our community and want to ensure that every contributor has an enjoyable and fulfilling experience.
We are committed to creating a friendly and respectful place for learning, teaching, and contributing.
Accordingly, everyone who participates in the Nebari project is expected to show respect and courtesy to other community members at all times.

You can find the [Nebari Code of Conduct on the `nebari-dev/governance` repository](https://github.com/nebari-dev/governance/blob/main/CODE_OF_CONDUCT.md) and it applies to all spaces managed by Nebari including, but not limited to, in-person and online focus groups and workshops, and communications online via GitHub.
